pub struct DeltaSnapshot {
pub qty: Quantity,
pub filled: Quantity,
pub limit_price_bits: Option<u64>,
pub stop_price_bits: Option<u64>,
}Expand description
Snapshot of the mutable fields seen on a tracked OpenOrdersDelta.
Used by the futures delta path to discriminate partial fills (filled increased), modify acknowledgements (qty / price / trigger_price changed), and no-op deltas (nothing changed) when a follow-up delta arrives.
Fields
qty: Quantityfilled: Quantitylimit_price_bits: Option<u64>stop_price_bits: Option<u64>Trait Implementations
Sourceimpl Clone for DeltaSnapshot
impl Clone for DeltaSnapshot
Sourcefn clone(&self) -> DeltaSnapshot
fn clone(&self) -> DeltaSnapshot
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeltaSnapshot
impl Debug for DeltaSnapshot
Sourceimpl PartialEq for DeltaSnapshot
impl PartialEq for DeltaSnapshot
impl Copy for DeltaSnapshot
impl StructuralPartialEq for DeltaSnapshot